@@ -94,7 +94,8 @@ verify_email_module <- function(input, output, session) {
             ),
             query = list(
               user_uid = session$userData$user()$user_uid
-            )
+            ),
+            config = list(http_version = 0)
           )
 
           res_content <- jsonlite::fromJSON(
@@ -144,7 +145,8 @@ verify_email_module <- function(input, output, session) {
           user_uid = session$userData$user()$user_uid,
           app_uid = getOption("polished")$app_uid
         ),
-        encode = "json"
+        encode = "json",
+        config = list(http_version = 0)
       )
 
       if (!identical(httr::status_code(res), 200L)) {
@@ -154,14 +156,22 @@ verify_email_module <- function(input, output, session) {
         stop(res_content, call. = FALSE)
       }
 
-      shinyFeedback::showToast("success", paste0("Verification email send to ", hold_email))
+      shinyFeedback::showToast(
+        "success",
+        paste0("Verification email send to ", hold_email),
+        .options = polished_toast_options
+      )
     }, error = function(err) {
 
 
       print("[polished] error - resending verification email")
       print(err)
 
-      shinyFeedback::showToast("error", "Error resending verification email")
+      shinyFeedback::showToast(
+        "error",
+        "Error resending verification email",
+        .options = polished_toast_options
+      )
     })
 
   })
