@@ -7,6 +7,6 @@ app_config <- config::get()
 # configure polished
 global_sessions_config(
   app_name = "polished_example_01",
-  api_key = app_config$api_key#,
-  #api_url = "http://localhost:8080"
+  api_key = app_config$api_key,
+  api_url = app_config$api_url
 )
